import { csv, select,legendColor } from 'd3';
import { scatterPlot } from './scatterPlot';


const csvUrl = 'https://gist.githubusercontent.com/suchitra2602/8de9e8ad39cfca9b44df878d18545709/raw/0af4ff693137c295ea88c88de5ba011f17367b03/ice7';

// Data gets splits, using parsing
const parseRow = (d) => {
  d.Kernel.Length = +d.Kernel.Length;
  d.Kernel.Width= +d.Kernel.Width;
  d.Asymmetry.Coeff= +d.Asymmetry.Coeff;
  d.Kernel.Groove = +d.Kernel.Groove;

  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// values to be viewed on X-labels
const xValue = (d) => d.Asymmetry.Coeff;
const yValue = (d) => d.Kernel.Groove;
const rxValue = (d) => d.Kernel.Length;
const ryValue = (d) => d.Kernel.Width;
const speciesValue = (d) => d.Type;
const colorValue = d => d.Type;
const colorLabel = 'Types';

//Adding the legends
const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.Asymmetry.Coeff);
  const y = yValue((d) => d.Kernel.Groove);
  const marker = (d) => {
        	switch(d){
            case 1:
              return 'green';
            case 2:
              return 'yellow';
            default:
              return 'red';
          }
        }
  
  const marks = data.map((d) => ({
          x: xValue((d) => d.Asymmetry.Coeff),
          y: yValue((d) => d.Kernel.Groove),
          species: speciesValue(d),
          color: marker(speciesValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
  
  
//Defining scatterplot structure
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
    .margin({
      top: 35,
      right: 50,
      bottom: 80,
      left: 95,

    })
    .radius(5);
  
  
 const g = svg.append('g')
          .attr('transform', `translate(${100},${100})`);

      const colorLegendG = g.append('g')
          .attr('transform', `translate(${100}, 150)`);


//Declaring the shape and structure of data points  
svg
          .selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));
  
  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];
  
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);  /* Generates  'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length'*/
		svg.selectAll('text').remove();
    svg.call(plot);
    
      colorLegendG.append('text')
          .attr('class', 'legend-label')
          .attr('x', -70)
          .attr('y', -210)
          .style("font-style","italic")
          .style("stroke","black")
          .text(colorLabel);

   
// Title
svg.append("text").attr("x", 450).attr("y", 20).text("ICE-7 Iris Reusable Scatterplot").style("font-size", "35px").attr("alignment-baseline","middle")

// Add labels in the legend
svg.append("text").attr("x", 150).attr("y", 70).text("Setosa").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 100).text("Versicolor").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 130).text("Virginica").style("font-size", "20px").attr("alignment-baseline","middle")
    svg
        	.append("text")
        	.attr('transform', 'rotate(-90)')
        	.attr('x',0 - (height /2))
        	.attr("y",  height/12)
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
        	.text("Sepal Length"); 
    // Add points for legend
    svg.append("circle").attr("cx",130).attr("cy",70).attr("r", 6).style("fill", "green")
		svg.append("circle").attr("cx",130).attr("cy",100).attr("r", 6).style("fill", "yellow")
		svg.append("circle").attr("cx",130).attr("cy",130).attr("r", 6).style("fill", "red")
   // plot petal_width on x-axis
    if(i % columns.length==0) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","Ariel")
        	.style("font-weight","bold")
      		.text("Petal Width");
     // plot sepal_width on x-axis
    else if(i % columns.length==1) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","Ariel")
        	.style("font-weight","bold")
      		.text("Sepal Width");
     // plot petal_length on x-axis
    else if(i % columns.length==2) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","Ariel")
        	.style("font-weight","bold")
      		.text("Petal Length");
     // plot sepal_length on x-axis
       else 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","Ariel")
        	.style("font-weight","bold")
      		.text("Sepal Length");
    i++;
  }, 2000);// every 2 seconds change the visualization
};
main();



